@@ -95,7 +95,7 @@ powerly <- function(
 
     # Inform the user about the method status.
     if (verbose) {
-        cat("\n", "Method run completed (", as.numeric(round(method$duration, 4)), " sec):", sep = "")
+        cat("\n", "Method run completed (", round(method$duration, 4), " sec):", sep = "")
         cat("\n", " - converged: ", ifelse(method$converged, "yes", "no"), sep = "")
         cat("\n", " - iterations: ", method$iteration, sep = "")
         cat("\n", " - recommendation: ", method$step_3$samples["50%"], "\n", sep = "")
@@ -153,7 +153,7 @@ validate <- function(
 
     # Information regarding the results of the validation.
     if (verbose) {
-        cat("\n", "Validation completed (", as.numeric(round(validation$validator$duration, 4)), " sec):", sep = "")
+        cat("\n", "Validation completed (", round(validation$validator$duration, 4), " sec):", sep = "")
         cat("\n", " - sample: ", validation$sample, sep = "")
         cat("\n", " - statistic: ", validation$statistic, sep = "")
         cat("\n", " - measure at ", validation$percentile, " pert.: ", round(validation$percentile_value, 3), sep = "")
